################################################
######## STARD DSM vs non-DSM symptoms #########
######### carried out 02/2015-08/2015 ##########
################################################

# when '#DSM' appears below, it means the analysis was conducted on the  
# the 15 DSM symptoms of the IDS instead of all 28.

setwd("C:/Users/u0097060/Dropbox/Research/My Papers/1. First author publications/2015-JAD-DSM vs nonDSM symptoms/Analysis folder/statistics")

library(IsingFit)
library(stats)
library(bootnet)
library(qgraph)
library(effsize)
library(ggplot2)

#library(devtools)
#install_github("sachaepskamp/IsingSampler")
#install_github("sachaepskamp/qgraph")
#install_github("sachaepskamp/bootnet")

# careful, there are some IDS items in between we don't want to select, like averaged sleep, or 9A and 9B that are mostly missing
# variables are defined in document "STAR*D List of Variables and Attribteus for Form RA". careful, order is different in "STAR*D ROA questionnaire" document.


##### DATA PREPARATION
data<-read.csv("IDS_HAMD2.csv", head=T)
data[data == -999] <- NA
# old; 25 symptoms; data_sex <- subset(data, select=c(sex,IDS010203.1, IDS04.1:IDS09.1,IDS10.1, IDS11121314.1,IDS15.1:IDS30.1))
data_demographics<- subset(data, select=c(IDS_sum.1, age,sex,IDS01.1, IDS02.1, IDS03.1, IDS04.1:IDS09.1,IDS10.1, IDS1112.1, IDS1314.1,IDS15.1:IDS30.1))
data_demographics <-na.omit(data_demographics)
data_sex <- subset(data, select=c(sex,IDS01.1, IDS02.1, IDS03.1, IDS04.1:IDS09.1,IDS10.1, IDS1112.1, IDS1314.1,IDS15.1:IDS30.1))
data_sex <-na.omit(data_sex)
data.DSM <- subset(data_sex, select=c(IDS01.1, IDS02.1, IDS03.1, IDS04.1, IDS05.1, IDS1112.1, IDS1314.1, IDS15.1, IDS16.1, IDS18.1,IDS19.1, IDS20.1, IDS21.1, IDS23.1, IDS24.1))
data <- data_sex
data[1] <- NULL

#save data for mplus analysis
#library(foreign)
#write.foreign(data, "C:/Users/u0097060/Desktop/data.txt", "C:/Users/u0097060/Desktop/mydata.sps", package="SPSS")


symptoms=c("in1","in2", "in3", "hyp","sad", "irr", "anx", "rea", "var", "qua", "app", "wei",
           "con","bla","pes", "sui", "int","ene", "ple", "sex", "ret", "agi", "som", "sym", "pan", "gas", "inp", "par")

symptoms.DSM=c("in1","in2", "in3", "hyp","sad", "app", "wei", "con","bla","sui", "int","ene", "ple", "ret", "agi")


###### NETWORK ESTIMATION

### polychoric correlation matrices
names(data) [1:28] <- symptoms
cor.poly <- cor_auto(data) 
# DSM
names(data.DSM) [1:15] <- symptoms.DSM
cor.poly.DSM <- cor_auto(data.DSM) 

### plots
gr1 <- list(c(1,2,3,4,5,11,12,13,14,16,17,18,19,21,22), c(6,7,8,9,10,15,20,23,24,25,26,27,28)) 
#first group dsm symptoms, second non dsm symptoms

## plot full symptoms newtork 
graph.g<- EBICglasso(cor.poly, n = nrow(data))# make glasso matrix
qgraph(graph.g, labels=symptoms, layout="spring", vsize=4, groups=gr1, 
       color=c('#bbbbbb','#ffffff'), 
       #+posCol='orange', negCol='blue', 
       cut=0)

# heatmap 
# col2 <- colorRampPalette(c("#c33131","white","#008200"))
# cp1<-graph.g[c(18,5,24,17,19,13,25,11,2,7,3,28,1,21,27,8,16,15,23,6,12,22,20,4,26,9,10), c(18,5,24,17,19,13,25,11,2,7,3,28,1,21,27,8,16,15,23,6,12,22,20,4,26,9,10)]
# corrplot(cp1, method="color", col=col2(21))

## plot DSM symptoms only
graph.g.DSM<- EBICglasso(cor.poly.DSM, n = nrow(data.DSM))# make glasso matrix
qgraph(graph.g.DSM, labels=symptoms.DSM, layout='spring', vsize=4, cut=0, mininum=.48, color='#bbbbbb')

# heatmap 
# dev.off()
# cp2<-graph.g.DSM[c(12,11,6,8,2,5,3,13,1,10,9,14,7,4,15), c(12,11,6,8,2,5,3,13,1,10,9,14,7,4,15)]
# corrplot(cp2, method="color", col=col2(21))




##### CENTRALITY ESTIMATION
## all symptoms
c.cor.glasso<- centrality(graph.g) 

#revision: correlate centralities and plot
cor(c.cor.glasso$InDegree, c.cor.glasso$Closeness)     #0.7705173
cor(c.cor.glasso$InDegree, c.cor.glasso$Betweenness)   #0.6602272
cor(c.cor.glasso$Betweenness, c.cor.glasso$Closeness)  #0.6941678
centralityPlot(graph.g)

## DSM symptoms
c.cor.glasso.DSM<- centrality(graph.g.DSM)

#revision: correlate centralities and plot
cor(c.cor.glasso.DSM$InDegree, c.cor.glasso.DSM$Closeness)     #0.6424984
cor(c.cor.glasso.DSM$InDegree, c.cor.glasso.DSM$Betweenness)   #0.5627927
cor(c.cor.glasso.DSM$Betweenness, c.cor.glasso.DSM$Closeness)  #0.6554732
centralityPlot(graph.g.DSM)

#####  CENTRALIY COMPARISON

### define the shizzle
list.dsm.l<-c.cor.glasso$InDegree
list.dsm.b<-c.cor.glasso$Betweenness
list.dsm.c<-c.cor.glasso$Closeness
DSM<-c(1,2,3,4,5,11,12,13,14,16,17,18,19,21,22) # dsm symptoms
noDSM<-c(6,7,8,9,10,15,20,23,24,25,26,27,28) # non dsm symptoms
noDSM.small<-c(6,7,8,15,20,23,24,25,26,27,28) # non dsm symptoms without 2 centrality outlier symptoms
disagr<-c(1,2,3,4,11,12,17,19,21,22) # disaggregated symptoms
normal<-c(5,6,7,8,9,10,13,14,15,16,18,20,23,24,25,26,27,28) # non disaggregated symptom

A<-list.dsm.l[DSM]                  #node strength
B<-list.dsm.l[noDSM]
C<-list.dsm.l[noDSM.small]
D<-list.dsm.l[disagr]
E<-list.dsm.l[normal]
Ab<-list.dsm.b[DSM]                 #betweenness
Bb<-list.dsm.b[noDSM]
Cb<-list.dsm.b[noDSM.small]
Db<-list.dsm.b[disagr]
Eb<-list.dsm.b[normal]
Ac<-list.dsm.c[DSM]                 #closeness
Bc<-list.dsm.c[noDSM]
Cc<-list.dsm.c[noDSM.small]
Dc<-list.dsm.c[disagr]
Ec<-list.dsm.c[normal]


### compare degree centralies DSM vs non DSM

#node strength

(sum(A))/15 # average centrality dsm symptom: 0.8822554
(sum(B))/13 # average centrality no dsm symptom: 0.6711173
t.test(A,B) #p=0.03589

realized.dif = mean(A)-mean(B); realized.dif 
set.seed(6492)
strength = stack(list(A=A, B=B))
values = strength$values
ind = strength$ind
Nsim=10000
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp = sample(ind)
  difs[i] = mean(values[ind.samp=="B"])-mean(values[ind.samp=="A"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.028


#betweenness
(sum(Ab))/15    # average centrality dsm symptom: 48.93333
(sum(Bb))/13    # average centrality no dsm symptom: 24.61538
t.test(Ab,Bb)   #t = 1.6776, df = 21.459, p-value = 0.1079

realized.dif = mean(Ab)-mean(Bb); realized.dif 
set.seed(6494)
strength = stack(list(A=Ab, B=Bb))
values = strength$values
ind = strength$ind
Nsim=10000
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp = sample(ind)
  difs[i] = mean(values[ind.samp=="B"])-mean(values[ind.samp=="A"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.1188

#closeness
(sum(Ac))/15    # average centrality dsm symptom: 0.001718065
(sum(Bc))/13    # average centrality no dsm symptom: 0.001662244
t.test(Ac,Bc)   # t = 0.48059, df = 23.956, p-value = 0.6352

realized.dif = mean(Ac)-mean(Bc); realized.dif 
set.seed(6494)
strength = stack(list(A=Ac, B=Bc))
values = strength$values
ind = strength$ind
Nsim=10000
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp = sample(ind)
  difs[i] = mean(values[ind.samp=="B"])-mean(values[ind.samp=="A"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.6366




### compare degree centralies DSM vs non DSM when excluding 2 centrality outliers VAR and QUA

# node strength
(sum(A))/15 # average centrality dsm symptom: 0.882
(sum(C))/11 # average centrality no dsm symptom: 0.769
t.test(A,C) #p=0.1325

realized.dif = mean(A)-mean(C); realized.dif
set.seed(6292)
strength = stack(list(A=A, C=C))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="C"])-mean(values[ind.samp=="A"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.126


# betweenness
(sum(Ab))/15 # average centrality dsm symptom: 48.93333
(sum(Cb))/11 # average centrality no dsm symptom: 29.09091
t.test(Ab,Cb) #p=0.1923

realized.dif = mean(Ab)-mean(Cb); realized.dif
set.seed(6292)
strength = stack(list(A=Ab, C=Cb))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="C"])-mean(values[ind.samp=="A"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.279


# closeness
(sum(Ac))/15 # average centrality dsm symptom:  0.001718065
(sum(Cc))/11 # average centrality no dsm symptom: 0.001779593
t.test(Ac,Cc) #p=0.4914

realized.dif = mean(Ac)-mean(Cc); realized.dif
set.seed(6192)
strength = stack(list(A=Ac, C=Cc))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="C"])-mean(values[ind.samp=="A"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 1.4758



### compare degree centralies aggregate vs disaggregate

#node strength
sum(D)/10 # average centrality disaggr symptom: 0.831
sum(E)/18 # average centrality non disaggr symptom: 0.759
t.test(D,E) #p=0.862

realized.dif = mean(D)-mean(E); realized.dif
set.seed(6497)
strength = stack(list(D=D, E=E))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="E"])-mean(values[ind.samp=="D"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.491

#betweenness
sum(Db)/10 # average centrality disaggr symptom: 32
sum(Eb)/18 # average centrality non disaggr symptom: 40.77778
t.test(Db,Eb) #p=0.5215

realized.dif = mean(Db)-mean(Eb); realized.dif
set.seed(6297)
strength = stack(list(D=Db, E=Eb))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="E"])-mean(values[ind.samp=="D"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 1.4076

#closeness
sum(Dc)/10 # average centrality disaggr symptom: 0.831
sum(Ec)/18 # average centrality non disaggr symptom: 0.759
t.test(Dc,Ec) #p=0.1806

realized.dif = mean(Dc)-mean(Ec); realized.dif
set.seed(6497)
strength = stack(list(D=Dc, E=Ec))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="E"])-mean(values[ind.samp=="D"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 1.7594


### compare glasso associations within / across clusters (DSM and non-DSM); A: DSM symptoms associations with each other; B: no DSM symptoms with each  other; C: associations across clusters. numbers from excel sheet.
A.list<-c(0.263,0.079,0.296,-0.059,-0.135,-0.211,0.035,0.000,0.028,0.000,0.060,0.000,0.000,0.009,0.000,0.012,0.017,0.028,0.000,0.000,0.000,0.000,0.000,0.000,0.113,0.000,0.000,0.000,0.020,0.008,0.000,0.000,0.000,0.000,0.049,0.005,0.020,0.000,0.014,0.051,0.000,0.024,0.043,0.084,0.125,0.000,0.000,0.002,0.000,0.000,0.053,0.002,0.027,-0.029,0.000,0.480,0.040,0.000,0.039,0.000,0.087,0.021,0.000,0.000,0.162,0.035,0.000,0.053,0.021,0.060,0.000,0.162,0.000,0.076,0.000,0.119,0.092,0.035,0.076,0.012,0.000,0.000,0.000,0.024,0.016,0.010,0.029,0.180,0.000,0.020,0.000,0.003,0.055)
B.list<-c(0.100,0.004,0.000,0.000,0.000,0.052,0.046,0.070,0.000,0.000,0.000,0.112,0.000,0.000,0.000,0.000,0.000,0.000,0.000,0.000,0.053,0.347,0.023,0.001,0.000,0.000,0.000,0.000,0.000,0.000,0.000,0.000,0.000,-0.064,0.000,0.022,0.000,0.011,0.000,0.019,0.092,0.000,0.000,0.000,0.002,0.000,0.049,0.022,0.188,0.158,0.000,0.094,0.000,0.050,0.081,0.000,0.000,0.023,0.000,0.000,0.087,0.245,0.000,0.000,0.000,0.007,0.000,0.015,0.000,0.025,-0.014,0.000,0.014,0.000,0.000,0.000,0.000,0.006,0.000,0.192,0.000,0.117,0.006,0.062)
C.list<-c(0.066,0.034,0.000,0.000,0.000,0.000,0.000,0.041,0.016,0.000,0.000,0.023,0.000,0.056,0.000,0.000,0.048,0.075,0.000,0.000,0.000,0.000,0.000,0.012,0.010,0.000,0.000,0.000,0.000,0.002,0.072,0.000,0.000,0.000,0.000,0.000,0.000,0.027,0.000,0.151,0.035,0.071,0.028,0.031,0.000,0.006,0.000,0.040,0.000,0.001,0.000,0.017,0.000,0.009,0.011,0.000,0.055,0.108,0.000,0.021,0.009,0.000,0.000,0.000,0.044,0.031,0.014,0.000,0.000,0.000,0.000,0.000,0.000,0.000,0.025,0.000,0.038,0.015,0.000,0.000,0.000,0.000,0.000,0.000,0.040,0.000,0.000,0.000,0.000,0.000,0.007,0.000,0.000,0.090,0.133,0.179,0.000,0.000,0.000,0.000,0.000,0.000,0.078,0.000,0.001,0.000,0.099,0.048,0.000,0.000,0.000,0.000,0.027,0.000,0.003,0.040,0.000,0.128,0.105,0.000,0.012,0.050,0.000,0.000,0.013,0.000,0.036,0.026,0.000,0.024,0.000,0.021,0.004,0.000,0.000,0.026,0.002,0.043,0.000,0.000,0.000,0.079,0.084,0.000,0.015,0.000,0.018,0.115,0.103,0.090,0.022,0.002,0.000,0.011,0.202,0.036,0.000,0.003,0.000,0.000,0.000,0.023,0.000,0.277,0.072,0.000,0.000,0.050,0.000,0.296,0.000,0.000,0.000,0.036,0.043,0.062,0.055,0.000,0.015,0.026,0.000,0.044,0.000,0.000,0.000,0.000,0.000,0.005,0.000,0.017,0.086,0.012,0.001,0.022,0.134,0.000,0.012,0.025,0.131,0.000,0.000)
F<-abs(A.list)
G<-abs(B.list)
H<-abs(C.list)

mean(F)   # 0.041
sd(F)     # 0.074
mean(G)   # 0.029
sd(G)     # 0.060
mean(H)   # 0.023
sd(H)     # 0.045

t.test(F,G) #p=0.257  DSM vs noDSM
t.test(F,H) #p=0.036  DSM vs cross
t.test(G,H) #p=0.409  noDSM vs cross

realized.dif = mean(F)-mean(G); realized.dif
set.seed(6497)
strength = stack(list(F=F, G=G))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="G"])-mean(values[ind.samp=="F"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.268

realized.dif = mean(G)-mean(H); realized.dif
set.seed(6497)
strength = stack(list(G=G, H=H))
values = strength$values
ind = strength$ind
difs = vector(length=Nsim)
for(i in 1:Nsim){
  ind.samp     = sample(ind)
  difs[i] = mean(values[ind.samp=="G"])-mean(values[ind.samp=="H"])
}
hist(difs)
abline(v=realized.dif,col="red")
difs = sort(difs)
mean(difs>=realized.dif)*2  # 2-tailed test: 0.358




##### SYMPTOM ANALYSES
dev.off()
par(mfrow=c(2,1))
plot(colMeans(data),type="b",axes=F,ann=F, ylim=c(0,3))
axis(1, at=1:28, lab=symptoms, las=2)
axis(2)

plot(apply(data,2,sd), type="b",axes=F,ann=F, ylim=c(0,2))
axis(1, at=1:28, lab=symptoms, las=2)
axis(2)

cor(colMeans(data),apply(data,2,sd)) # correlation M & SD: 0.3678507
cor(colMeans(data),c.cor.glasso$InDegree) # correlation M & centrality: 0.3592089
cor(apply(data,2,sd),c.cor.glasso$InDegree) # correlation SD & centrality: -0.2002129

# compare symptom means DSM vs non DSM
mean(colMeans(data)[c(1,2,3,4,5,11,12,13,14,16,17,18,19,21,22)]) # 1.38
mean(colMeans(data)[c(6,7,8,9,10,15,20,23,24,25,26,27,28)]) # 1.18
mean(apply(data,2,sd)[c(1,2,3,4,5,11,12,13,14,16,17,18,19,21,22)]) # 0.99
mean(apply(data,2,sd)[c(6,7,8,9,10,15,20,23,24,25,26,27,28)]) # 1.03

wilcox.test(colMeans(data)[c(1,2,3,4,5,11,12,13,14,16,17,18,19,21,22)], colMeans(data)[c(6,7,8,9,10,15,20,23,24,25,26,27,28)]) #0.2945
wilcox.test(apply(data,2,sd)[c(1,2,3,4,5,11,12,13,14,16,17,18,19,21,22)], apply(data,2,sd)[c(6,7,8,9,10,15,20,23,24,25,26,27,28)]) #0.7168



##### DEMOGRAPHICS
mean(data_demographics$age)
sd(data_demographics$age)
mean(data_sex$sex)
mean(data_age$IDS_sum.1)
sd(data_demographics$IDS_sum.1 )
range(data_demographics$IDS_sum.1)




##### BOOTSTRAPPING CENTRALITY ESTIMATES (via BOOTNET)
# bootnet was not really finished back then, so this particular code may not run in the future
# it also explains why some of the syntax looks rather weird ;)
library(devtools)
devtools::install_github("sachaepskamp/qgraph")
devtools::install_github("sachaepskamp/bootnet")

### All 28 symptoms network first
m1<-bootnet(data, nBoots=20, default="EBICglasso")
#plot(m1, "strength", plot = "interval", order = "value", decreasing = T)
#plot(m1, "strength", plot = "line", order = "value", decreasing = T)

as.data.frame(summary(m1,"strength")) # get CI

### Plot
#plot(m1, "strength", plot = "interval")
#plot(m1, "strength", plot = "line")
a <-c("ene", "sad", "sym", "int", "ple", "con", "pan", "app", "in2", "anx", "bla", "in3", "par", "in1", "ret", "inp", "rea", "sui", "pes", "som", "irr", "wei", "agi", "sex", "hyp", "gas", "var", "qua")
b <-c(1.15220099, 1.10797504,1.05083488, 1.04075482, 1.04040974, 1.03017191, 1.00986077,0.97687106, 0.97651034, 0.96653016, 0.91066171,0.87499607, 0.82549958, 0.79714062, 0.76731441, 0.74983882, 0.73617558, 0.72655416, 0.70751901, 0.68061369, 0.67726459, 0.65987862, 0.6046725, 0.586737, 0.56771942, 0.46720748, 0.1767481, 0.08969517) #mean
c <-c(1.068, 1.027,0.959,0.968, 0.964,0.938,0.937, 0.877, 0.892,0.902, 0.829, 0.799,0.745, 0.723, 0.685,0.687, 0.694, 0.658, 0.647, 0.616, 0.606,0.609,0.543, 0.517,0.496,0.416, 0.136,0.063) #2.5% CI
d <-c(1.273, 1.187,1.130, 1.144, 1.118,  1.112, 1.115, 1.053,1.069,1.054,  1.009,0.982, 0.919, 0.892,0.867,0.859,0.844,0.808,0.789, 0.770, 0.751, 0.760, 0.719,0.673,0.715, 0.561,0.308, 0.205) # 97.5% CI

df <- data.frame(a,b,c,d)
df <- transform(df, a = reorder(a, order(b, decreasing = T)))

GG1 <- ggplot(df, aes(x=as.factor(a), y=b, order=a))+
  geom_line(aes(group=1)) +
  geom_point(size = 3) +
  geom_smooth(aes(ymin = c, ymax = d, group=1), colour="black", size=1, stat = "identity") +
  theme_bw() +
  scale_x_discrete(name="28 IDS-C symptoms") +
  scale_y_continuous(name="Centrality", limits=c(0,1.3), breaks=c(0,0.25,0.5,0.75,1,1.25))
GG1 + 
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))
  
  
### DSM symptoms network
m2<-bootnet(data.DSM, nBoots=2000, default="EBICglasso")
plot(m2, "strength", plot = "line", order = "value", decreasing = T)
as.data.frame(summary(m2,"strength")) # get CI

### plot
a1 <-c("ene", "int","app", "con", "in2", "sad", "in3","ple","in1", "sui","bla",  "ret","wei","hyp","agi")
b1 <-c(0.955,0.944, 0.910, 0.894, 0.882, 0.880,0.853, 0.814, 0.730, 0.656,  0.646,0.635, 0.609, 0.560,0.472) #mean
c1 <-c(0.864, 0.870, 0.827,0.824, 0.806, 0.812,0.772, 0.748, 0.659,0.592,0.579, 0.564,  0.563,  0.479, 0.397) #2.5% CI
d1 <-c(1.043, 1.040,0.983, 0.966,  0.968,0.957,0.939,  0.888,0.821, 0.748,0.737,0.714,0.686, 0.694, 0.552) #97.5% CI

df1 <- data.frame(a1,b1,c1,d1)
df1 <- transform(df1, a1 = reorder(a1, order(b1, decreasing = T)))

GG2 <- ggplot(df1, aes(x=as.factor(a1), y=b1, order=a1))+
  geom_line(aes(group=1)) +
  geom_point(size = 3) +
  geom_smooth(aes(ymin = c1, ymax = d1, group=1), colour="black", size=1, stat = "identity") +
  theme_bw() +
  scale_x_discrete(name="15 IDS-C DSM criterion symptoms for depression") +
  scale_y_continuous(name="Centrality", limits=c(0,1.25), breaks=c(0,0.25,0.5,0.75,1,1.25)) 
GG2 + 
  theme(axis.text.x  = element_text(angle=90, vjust=0.5, size=12)) +
  theme(axis.text.y = element_text(size=12)) +
  theme(axis.title.x = element_text(size=14)) +
  theme(axis.title.y = element_text(size=14))
